#!/usr/bin/env lua
-- DESCR: optimize gain at φ=90°, optimize SWR for 50Ω feed, avoid radiation at φ=270° plus 115° in any direction
local worst_loss = 0.0
local forward, backward
local worst_forward = 1.0/0.0
local worst_backward = -1.0/0.0
local state = nil
local done
for line in io.lines() do
  if line:find(" ANTENNA INPUT PARAMETERS ") then
    state = "impedance"
    done = false
  elseif line:find(" RADIATION PATTERNS ") then
    state = "gain"
    forward = -1.0/0.0
    backward = -1.0/0.0
    done = false
  elseif state == "impedance" then
    local real, imag = line:match("^ +[-+0-9.Ee]+ +[-+0-9.Ee]+ +[-+0-9.Ee]+ +[-+0-9.Ee]+ +[-+0-9.Ee]+ +[-+0-9.Ee]+ +([-+0-9.Ee]+) +([-+0-9.Ee]+) ")
    if real then
      real, imag = tonumber(real), tonumber(imag)
      if real <= 0 then
        print("-999")
        return
      end
      real = real / 50
      imag = imag / 50
      local loss = math.log(4*real / (real*real + 2*real + imag*imag + 1), 10) * 10
      worst_loss = math.min(worst_loss, loss)
      done = true
    elseif done then
      state = nil
    end
  elseif state == "gain" then
    local theta, phi, gain = line:match("^ +([-+0-9.Ee]+) +([-+0-9.Ee]+) +[-+0-9.Ee]+ +[-+0-9.Ee]+ +([-+0-9.Ee]+) ")
    if gain then
      theta = tonumber(theta)
      phi = tonumber(phi)
      gain = tonumber(gain)
      if theta == 90 and phi == 90 then
        forward = math.max(forward, gain)
      else
        local alpha = math.asin(math.sin(theta/180*math.pi) * math.sin(phi/180*math.pi)) / math.pi * 180
        if alpha < 25.001 then
          backward = math.max(backward, gain)
        end
      end
      done = true
    elseif done then
      if forward > -1.0/0.0 then
        worst_forward = math.min(worst_forward, forward)
      end
      if backward > -1.0/0.0 then
        worst_backward = math.max(worst_backward, backward)
      end
      state = nil
    end
  end
end
local backward_penalty = math.log(
  10^(worst_forward/20) / ( 10^(worst_forward/20) + 10^(worst_backward/20) ),
  10
) * 20
print(worst_forward + backward_penalty + 2*worst_loss)
