#!/usr/bin/env lua
-- DESCR: optimize worst gain (considering all given directions), optimize SWR for 50Ω feed
local worst_loss = 0.0
local worst_gain = 1.0/0.0
local state = nil
local done
for line in io.lines() do
  if line:find(" ANTENNA INPUT PARAMETERS ") then
    state = "impedance"
    done = false
  elseif line:find(" RADIATION PATTERNS ") then
    state = "gain"
    forward = -1.0/0.0
    done = false
  elseif state == "impedance" then
    local real, imag = line:match("^ +[-+0-9.Ee]+ +[-+0-9.Ee]+ +[-+0-9.Ee]+ +[-+0-9.Ee]+ +[-+0-9.Ee]+ +[-+0-9.Ee]+ +([-+0-9.Ee]+) +([-+0-9.Ee]+) ")
    if real then
      real, imag = tonumber(real), tonumber(imag)
      if real <= 0 then
        print("-999")
        return
      end
      real = real / 50
      imag = imag / 50
      local loss = math.log(4*real / (real*real + 2*real + imag*imag + 1), 10) * 10
      worst_loss = math.min(worst_loss, loss)
      done = true
    elseif done then
      state = nil
    end
  elseif state == "gain" then
    local gain = line:match("^ +[-+0-9.Ee]+ +[-+0-9.Ee]+ +[-+0-9.Ee]+ +[-+0-9.Ee]+ +([-+0-9.Ee]+) ")
    if gain then
      gain = tonumber(gain)
      if gain > -1.0/0.0 then
        worst_gain = math.min(worst_gain, gain)
      end
      done = true
    elseif done then
      state = nil
    end
  end
end
print(worst_gain + 2*worst_loss)
